@@ -7,6 +7,8 @@ class Request:
     """Request base data class"""
     user_id: Optional[int]
     username: Optional[str]
+    process_id: Optional[str]
+    parent_job_id: Optional[str]
     job_id: Optional[str]
     op_id: Optional[str]
     job_child_idx_list: Optional[List[int]]
